/*
  Run this program and then resize the window so that is no longer
  a square window. Notice how the image is not redrawn until you
  "release" the mouse.

  We can fix this by registering a GLUT "reshape event handler"
  that calls the glViewport() and display() functions every time
  there is a "reshape" event (see the next program, circle-v1.c).
*/
#include <stdio.h>
#include <math.h>

#if defined _WIN32 || defined _WIN64
#  include <windows.h>
#endif

#ifdef __APPLE__
#  include <GLUT/glut.h>
#else
#  include <GL/glut.h>
#endif


/* Prototype for the display() callback function */
void display(void);


int main(int argc, char** argv)
{
   /* Standard GLUT initialization */
   glutInit(&argc,argv);
   glutInitDisplayMode (GLUT_SINGLE | GLUT_RGB); /* default, not needed */
   glutInitWindowSize(500, 500);     /* 500 x 500 pixel window */
   glutInitWindowPosition(100, 100); /* place window near top left of display */
   glutCreateWindow("Circle v0");    /* window title */
   glutDisplayFunc(display);         /* display callback invoked when window is redrawn */


   /* Initialize OpenGL state */
   glShadeModel(GL_FLAT);            /* default is GL_SMOOTH */
   glFrontFace(GL_CCW);
   glPolygonMode(GL_FRONT, GL_LINE);
   glPolygonMode(GL_BACK, GL_FILL);
   glClearColor(1.0, 1.0, 1.0, 1.0); /* white background */
   glColor3f(1.0, 0.0, 0.0);         /* draw in red */
   /* set up viewing */
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(-2.0, 2.0, -2.0, 2.0); /* viewing volume */
   glMatrixMode(GL_MODELVIEW);

   /* Enter event loop */
   glutMainLoop();

   return 0;  /* we never get here */
}//main()


/* The display() callback function */
void display( void )
{
   const double PI = 3.14159265;
   int numPoints = 100;
   int n;

   glClear(GL_COLOR_BUFFER_BIT);  /* clear the window */

   glBegin(GL_TRIANGLE_FAN);
     glVertex2f(0.0, 0.0);
     for (n = 0; n <= numPoints; n++)
        glVertex2f(cos((n/(double)numPoints)*2*PI), sin((n/(double)numPoints)*2*PI));
   glEnd();

   glFlush();

   printf("We got a \"display()\" event\n");
}//display()
