/*
   This program creates many, overlapping viewports within one screen window.
   The main purpose of this demo is to show that viewports do not need to
   be disjoint (though they often are). The most common use for overlapping 
   viewports is to draw a "window within a window" like you sometimes see in 
   TV sets or video games.
*/
#include <iostream>
#include <fstream>

#if defined _WIN32 || defined _WIN64
#  include <windows.h>
#endif

#ifdef __APPLE__
#  include <GLUT/glut.h>
#else
#  include <GL/glut.h>
#endif

using namespace std;

/* Prototypes for the display() and reshape() callback functions */
void display(void);
void reshape(int, int);

int windowWidth;    // set by the reshape() callback function
int windowHeight;   // set by the reshape() callback function


void drawGRSFile(const char *fileName)
{
   fstream inStream;
   inStream.open(fileName, ios::in);  // open the GRS file
   if(inStream.fail()){cout << "Can't open GRS file: " << fileName; return;};

   // read the comment lines
   char str[80];
   inStream.getline(str, 80, '\n');
   while (str[0] != '*')
      inStream.getline(str, 80, '\n');

   // read the figure extents
   GLfloat left, top, right, bottom;
   inStream >> left >> top >> right >> bottom;

   // set the world window to just hold the image from the GRS file
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(left, right, bottom, top);  // world window

   GLint numPolylines;
   inStream >> numPolylines;              // read the number of polylines
   for(int j = 0; j < numPolylines; j++)  // read each polyline
   {
      GLint numVertices;
      inStream >> numVertices;      // read the number of vertices in this polyline
      GLfloat x ,y;
      glBegin(GL_LINE_STRIP);       // draw this polyline
        for (int i = 0; i < numVertices; i++)
        {
           inStream >> x >> y;  // read the next world coordinate pair
           glVertex2f(x, y);
        }
      glEnd();
   }
   glFlush();        // forces the drawing to take place
   inStream.close(); // close the GRS file
}//drawGRSFile()



int main(int argc, char **argv)
{
   /* Standard GLUT initialization */
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
 //glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGB);   
   glutInitWindowSize(500,500);
   glutInitWindowPosition(200, 200);
   glutCreateWindow("Hw 2 Demo");
   // window event callback functions
   glutDisplayFunc(display);
   glutReshapeFunc(reshape);

   /* Initialize OpenGL state */
   glClearColor(1.0f,1.0f,1.0f,1.0f);  // background is white

   /* Enter event loop */
   glutMainLoop();

   return 0;  /* we never get here */
}//main()


/* The display() callback function */
void display(void)
{
   glClear(GL_COLOR_BUFFER_BIT);  // clear the screen buffer
   glColor3f(1.0f, 0.0f, 0.0f);   // draw in red

   // define a square viewport that is one third the size
   // of the smaller edge of the screen window
   int viewportWidth  = (windowHeight < windowWidth) ? windowHeight/3: windowWidth/3;
   int viewportHeight = viewportWidth;

   // draw the viewports along a diagonal that goes from the lower left hand
   // corner of the screen window up to the upper right hand corner
   int numOfViewports = 20;
   double deltaX = (windowWidth - viewportWidth) / (double)numOfViewports;
   double deltaY = (windowHeight - viewportHeight) / (double)numOfViewports;
   for (int i = 0; i <= numOfViewports; i++)
   {  // draw multiple viewports onto the screen window
      glViewport((int)(i*deltaX), (int)(i*deltaY), viewportWidth, viewportHeight);
      drawGRSFile("bronto.grs");
   }

 //glutSwapBuffers();  // using double buffering
   printf("We got a \"display()\" event\n");
}//display()


/* The reshape() callback function */
void reshape(int width, int height)
{
   windowWidth  = width;
   windowHeight = height;

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
   display();
}//reshape()