/*
   This program creates two viewports within the program's screen window.
   One view port is square (its aspect ratio is 1) and is anchored at the
   upper left hand corner of the screen window. The other viewport uses up
   the part of the screen window that is no used by the square viewport.
   The second viewport is either on the right of the square viewport or at 
   the bottom of the square viewport, depending on whether the screen window 
   has an aspect ratio greater than 1 or less than 1.
*/
#include <iostream>
#include <fstream>

#if defined _WIN32 || defined _WIN64
#  include <windows.h>
#endif

#ifdef __APPLE__
#  include <GLUT/glut.h>
#else
#  include <GL/glut.h>
#endif

using namespace std;

/* Prototypes for the display() and reshape() callback functions */
void display(void);
void reshape(int, int);

int windowWidth;    // set by the reshape() callback function
int windowHeight;   // set by the reshape() callback function


void drawGRSFile(const char *fileName)
{
   fstream inStream;
   inStream.open(fileName, ios::in);  // open the GRS file
   if(inStream.fail()){cout << "Can't open GRS file: " << fileName; return;};

   // read the comment lines
   char str[80];
   inStream.getline(str, 80, '\n');
   while (str[0] != '*')
      inStream.getline(str, 80, '\n');

   // read the figure extents
   GLfloat left, top, right, bottom;
   inStream >> left >> top >> right >> bottom;

   // set the world window to just hold the image from the GRS file
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(left, right, bottom, top);  // world window

   GLint numPolylines;
   inStream >> numPolylines;              // read the number of polylines
   for(int j = 0; j < numPolylines; j++)  // read each polyline
   {
      GLint numVertices;
      inStream >> numVertices;      // read the number of vertices in this polyline
      GLfloat x ,y;
      glBegin(GL_LINE_STRIP);       // draw this polyline
        for (int i = 0; i < numVertices; i++)
        {
           inStream >> x >> y;  // read the next world coordinate pair
           glVertex2f(x, y);
        }
      glEnd();
   }
   glFlush();        // forces the drawing to take place
   inStream.close(); // close the GRS file
}//drawGRSFile()



int main(int argc, char **argv)
{
   /* Standard GLUT initialization */
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
   glutInitWindowSize(500,500);
   glutInitWindowPosition(200, 200);
   glutCreateWindow("Hw 2 Demo");
   // window event callback functions
   glutDisplayFunc(display);
   glutReshapeFunc(reshape);

   /* Initialize OpenGL state */
   glClearColor(1.0f,1.0f,1.0f,1.0f);  // background is white

   /* Enter event loop */
   glutMainLoop();

   return 0;  /* we never get here */
}//main()


/* The display() callback function */
void display(void)
{
   glClear(GL_COLOR_BUFFER_BIT);  // clear the screen buffer

   // set up the square viewport
   int viewportWidth  = (windowHeight < windowWidth) ? windowHeight: windowWidth;
   int viewportHeight = (windowHeight < windowWidth) ? windowHeight: windowWidth;
   int viewportLLx = 0;
   int viewportLLy = windowHeight - viewportHeight;
   glViewport(viewportLLx, viewportLLy, viewportWidth, viewportHeight);
   // draw the image in the square viewport
   glColor3f(1.0f, 0.0f, 0.0f);
   drawGRSFile("bronto.grs");

   // set up the "extra" viewport
   if (windowHeight < windowWidth) // extra viewport on the right
   {
      viewportWidth  = windowWidth - windowHeight;
      viewportHeight = windowHeight;
      viewportLLx = windowHeight;
      viewportLLy = 0;
      glViewport(viewportLLx, viewportLLy, viewportWidth, viewportHeight);
      // draw the image in the "extra" viewport
      glColor3f(0.0f, 0.0f, 1.0f);  // blue
      drawGRSFile("bronto.grs");
   }
   else if (windowHeight > windowWidth) // extra viewport on the bottom
   {
      viewportWidth  = windowWidth;
      viewportHeight = windowHeight - windowWidth;
      viewportLLx = 0;
      viewportLLy = 0;
      glViewport(viewportLLx, viewportLLy, viewportWidth, viewportHeight);
      // draw the image in the "extra" viewport
      glColor3f(0.0f, 1.0f, 0.0f);  // green
      drawGRSFile("bronto.grs");
   }

   printf("We got a \"display()\" event\n");
}//display()


/* The reshape() callback function */
void reshape(int width, int height)
{
   windowWidth  = width;
   windowHeight = height;

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
   display();
}//reshape()