/*
   This version makes the viewport the whole program window, so the aspect ratio of the
   graph (the world window) is not preserved and the shape of the graph is distorted.
*/
#include <stdio.h>
#include <math.h>

#if defined _WIN32 || defined _WIN64
#  include <windows.h>
#endif

#ifdef __APPLE__
#  include <GLUT/glut.h>
#else
#  include <GL/glut.h>
#endif

#define graphTop      1.0
#define graphBottom  -0.22
#define graphLeft    -4.0
#define graphRight   ( - graphLeft )
#define graphWidth   ( graphRight - graphLeft )
#define graphHeight  ( graphTop - graphBottom )
#define aspectRatio  ( graphWidth/graphHeight )

void reshape(int, int);

int windowHeight;    // this is set by the reshape() callback function
int windowWidth;     // this is set by the reshape() callback function

void display(void)   // plot the sinc function, using world coordinates
{
   const float pi = 3.14159265358979;
   float x;

   glClear( GL_COLOR_BUFFER_BIT );

   // specify the viewport as the whole screen window
   glViewport(0,  0, windowWidth, windowHeight); // left, bottom, width, height (in pixels)


   glBegin(GL_LINE_STRIP);
      for(x = graphLeft; x < graphRight; x += 0.01)  // draw the graph
      {
         glVertex2f( x, sin(pi*x)/(pi*x) );
      }
   glEnd();

   glFlush();
}


int main(int argc, char** argv)
{
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
   // specify the screen window
   glutInitWindowSize(640, 480);       // width, height (in pixels)
   glutInitWindowPosition(100, 150);   // left, top (in pixels)
   glutCreateWindow("Sinc Function v1");
   glutDisplayFunc(display);
   glutReshapeFunc(reshape);

   glClearColor(1.0,1.0,1.0,0.0);
   glLineWidth(1.0);
   glColor3f(0.0f,0.0f,1.0f);

   // specify the world window
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(graphLeft, graphRight, graphBottom, graphTop); // in world coordinates

   glutMainLoop( );

   return 0;
}

/* The reshape() callback function */
void reshape(int width, int height)
{
   windowWidth  = width;
   windowHeight = height;

   display();
   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
}//reshape()